@@ -12,7 +12,7 @@ use Scalar::Util qw(blessed);
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 sub new {
     my ( $class, %params ) = @_;
@@ -155,13 +155,24 @@ sub _check_countries {
                 die "Unable to initialize Date::Holidays for country: $country\n";
             }
 
-            #TODO add handling of state and region
-            my $r = $dh->is_holiday(
+            my %prepared_parameters = (
                 year  => $params{'year'},
                 month => $params{'month'},
-                day   => $params{'day'},
+                day   => $params{'day'},                
             );
 
+            # did we receive special regions parameter?
+            if ($params{regions}) {
+                $prepared_parameters{regions} = $params{regions};
+            }
+
+            # did we receive special state parameter?
+            if ($params{state}) {
+                $prepared_parameters{state} = $params{state};
+            }
+
+            my $r = $dh->is_holiday(%prepared_parameters);
+
             if ($precedent_calendar eq $country) {
                 $self->{precedent_calendar} = $dh;
             }
@@ -170,11 +181,8 @@ sub _check_countries {
             if ($precedent_calendar and
                 $precedent_calendar ne $country) {
 
-                #TODO add handling of state and region
                 my $holiday = $self->{precedent_calendar}->is_holiday(
-                    year  => $params{'year'},
-                    month => $params{'month'},
-                    day   => $params{'day'},
+                    %prepared_parameters
                 );
 
                 # our precedent calendar dictates overwrite or nullification                
@@ -263,7 +271,7 @@ Date::Holidays - Date::Holidays::* adapter and aggregator for all your holiday n
 
 =head1 VERSION
 
-This POD describes version 1.02 of Date::Holidays
+This POD describes version 1.03 of Date::Holidays
 
 =head1 FEATURES
 
@@ -804,7 +812,7 @@ Test coverage in version 1.02
 
 =over
 
-=item * Alexander Nalobin, patch for using of Date::Holidays::RU, 1.02
+=item * Alexander Nalobin, patch for using of Date::Holidays::RU, 1.03
 
 =item * Gabor Szabo, patch assisting META data generation
 
