@@ -6,7 +6,7 @@ use vars qw($VERSION);
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 use constant DEFAULT_STATE => 'VIC';
 
@@ -17,7 +17,7 @@ sub holidays {
     my $state = $params{'state'} ? $params{'state'} : DEFAULT_STATE;
 
     if ($sub) {
-        return &{$sub}(year => $params{'year'}, state => $state, %params);
+        return &{$sub}(year => $params{'year'}, state => $state);
     } else {
         return;
     }
@@ -30,7 +30,7 @@ sub is_holiday {
     my $state = $params{'state'} ? $params{'state'} : DEFAULT_STATE;
 
     if ($sub) {
-        return &{$sub}($params{'year'}, $params{'month'}, $params{'day'},  $state, \%params);
+        return &{$sub}($params{'year'}, $params{'month'}, $params{'day'},  $state, {});
     } else {
         return;
     }
@@ -46,7 +46,7 @@ Date::Holidays::Adapter::AU - an adapter class for Date::Holidays::AU
 
 =head1 VERSION
 
-This POD describes version 1.02 of Date::Holidays::Adapter::AU
+This POD describes version 1.03 of Date::Holidays::Adapter::AU
 
 =head1 DESCRIPTION
 
